# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from . import chardet  # noqa: F401
from . import httpsig_cffi  # noqa: F401
from . import jwt  # noqa: F401
from . import idna  # noqa: F401
from . import six  # noqa: F401
from . import urllib3  # noqa: F401
from . import requests  # noqa: F401
